@@ -10,23 +10,23 @@ fn empty() {
 #[test]
 fn simple() {
     let ast = parse_html("<p>text</p>");
-    println!("{:#?}", ast.unwrap_or_default())
+    format!("{:#?}", ast.unwrap_or_default());
 }
 
 #[test]
 fn nested() {
     let ast = parse_html("<p>text<i>i</i><b>b</b></p>");
-    println!("{:#?}", ast.unwrap_or_default())
+    format!("{:#?}", ast.unwrap_or_default());
 }
 
 #[test]
 fn md_fragment() {
     let ast = parse_html(include_str!("md_fragment.html"));
-    println!("{:#?}", ast.unwrap_or_default())
+    assert_eq!(format!("{:#?}", ast.unwrap()), include_str!("md_fragment.yaml"))
 }
 
 #[test]
 fn md_full() {
     let ast = parse_html(include_str!("md_full.html"));
-    println!("{:#?}", ast.unwrap_or_default())
+    assert_eq!(format!("{:#?}", ast.unwrap()), include_str!("md_full.yaml"))
 }
