@@ -7,12 +7,6 @@ fn empty() {
     assert_eq!(ast, ASTKind::statements(vec![], None))
 }
 
-#[test]
-fn test() {
-    let ast = parse_common_markdown("text");
-    println!("{:#?}", ast.unwrap_or_default())
-}
-
 #[test]
 fn test3() {
     let ast = parse_common_markdown(include_str!("markdown-it.md"));
